lissajousgifs

package module
v0.0.0-...-b3f80b9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2023 License: MIT Imports: 8 Imported by: 0

README

lissajousgifs

GitHub go.mod Go version Go Report Card GitHub Workflow Status (with branch) GitHub GitHub code size in bytes

lissajousgifs is a Go module that generates a random Lissajous GIF animation from a sequence of encoded bit-mapped images.

Installation

Use the Go CLI tool go to install lissajousgifs.

go get github.com/pascalallen/lissajousgifs

Usage

...

import "github.com/pascalallen/lissajousgifs"

...

// TODO

...

Testing

Run tests and create coverage profile:

go test -covermode=count -coverprofile=coverage.out

View test coverage profile:

go tool cover -html=coverage.out

Contributing

Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

License

MIT

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GenerateGif

func GenerateGif()

Types

This section is empty.

Jump to